function newPol = bgppolcy(K,tk,ddk,kDeduct, tc,C, L,X,tw,Lold,Xold,to,...
    xDeduct,xEarn,sx, grn,DY,GY,TrY, taxAdj, BTaggr,taxb, Xx,sxx, dbg)
% Compute endogenous policy to balance the budget along BGP
% ---------------------------------------
% IN:
%   K,L,X       = aggregates
%   Lold,Xold   = as defined in taxrev()
%   grn         = growth rate + population growth rate ((1+gr) * (1+n))
%   DY0         = Debt/Y
%   GY0, TrY0   = gov. spending or transfers / Y
%   tw, tk, to,tc = tax rates
%   taxAdj      = indicates which policy adjusts
%   BTaggr      = aggregate level of bequests at date 1
%   taxb        = tax on bequests
%   Xx          = aggregate goods inputs in h1 investment
%   sxx         = subsidy rate on Xx
% OUT:
%   changed policy variable; only one of them will be changed

% REM:
% - twAdjustsG means that ONLY tw adjusts, NOT to
% AUTHOR: Lutz Hendricks, 1993-97
% ---------------------------------------

% *** GLOBALS ***

    global twAdjustsG tkAdjustsG DYAdjustsG TrYAdjustsG GYAdjustsG
    global tcAdjustsG toAdjustsG
    global iniPop

    polMax = 1e7;
    polMin = -1e7;


% ******  INPUT CHECK  ****************

    if taxAdj == tkAdjustsG
        abort('Not implemented for tk adjusting')
    elseif taxAdj == twAdjustsG
        tw = 0;
        polMax = 1.5;
        polMin = -1.5;
    elseif taxAdj == GYAdjustsG
        GY = 0;
        polMax = 1.5;
        polMin = -1.5;
    elseif taxAdj == TrYAdjustsG
        TrY = 0;
        polMax = 1.5;
        polMin = -1.5;
    elseif taxAdj == DYAdjustsG
        DY = 0;
    elseif taxAdj == tcAdjustsG
        tc = 0;
        polMax = 1.5;
        polMin = -1.5;
    else
        abort('BgpPolcy: Invalid taxAdj')
    end

    % ** Special case of no government
    if all([ DY, GY, TrY, tw, tk, tc, to, sx, sxx ] == 0)
        newPol = 0;
        return;
    end

    if dbg > 5
        if any([K,L,X,Lold,Xold,C] > 1e6)
            abort('Inputs too large')
        end
        if any([K,L,C] < 1e-6)
            abort('Inputs too small')
        end
    end


% ******  AUXILIARY VARIABLES  ********

    [Y,MPK,MPL] = prodfct(K, L);
    Ynet = Y - ddk*K;

    % ** Tax revenue without the endogenous tax
    Tax = taxrev(MPK,K,tk,ddk,kDeduct, tc,C, MPL,L,X,tw, Lold,Xold,...
        to,xDeduct,xEarn,sx, BTaggr,taxb, Xx,sxx);

    Debt = DY * Y;

    % ** Surplus that has to be balanced by the endogenous policy
    % ** This would be wrong if tk were to adjust!!
    r = rnet(K./L, tk, kDeduct, ddk);
    Surplus = Tax - Ynet*TrY - Y*GY - Debt*(r - grn+1);


% ************  SET POLICY  ************

    if taxAdj == tkAdjustsG
        abort('Not implemented for tk adjusting')
    elseif taxAdj == twAdjustsG
        TaxBase = MPL*L - X.*xDeduct;
        newPol = - Surplus / TaxBase;
    elseif taxAdj == GYAdjustsG
        newPol = Surplus / Ynet;
    elseif taxAdj == TrYAdjustsG
        newPol = Surplus / Ynet;
    elseif taxAdj == DYAdjustsG
        newPol = Surplus / Y / (r-grn+1);
    elseif taxAdj == tcAdjustsG
        TaxBase = C;
        newPol = - Surplus / TaxBase;
    end



% ***********  CHECK  *************

    if dbg > 5
        % Set the changed variable to its new value
        if taxAdj == tkAdjustsG
            abort('Not implemented for tk adjusting')
        elseif taxAdj == twAdjustsG
            tw = newPol;
        elseif taxAdj == GYAdjustsG
            GY = newPol;
        elseif taxAdj == TrYAdjustsG
            TrY = newPol;
        elseif taxAdj == DYAdjustsG
            DY = newPol;
        elseif taxAdj == tcAdjustsG
            tc = newPol;
        end

        GRev = taxrev(MPK,K,tk,ddk,kDeduct, tc,C,...
            MPL,L,X,tw, Lold,Xold,to,xDeduct,xEarn,sx, BTaggr,taxb,Xx,sxx);
        GSpend = TrY*Ynet + GY*Y + (r-grn+1)*DY*Y;
        Deficit = GRev - GSpend;
        if abs(Deficit) > 1e-4
            Deficit
            warnmsg('BGPPolcy: Budget constraint violated')
        end
        if 0
            disp([ 'Gov. Rev.: ', num2str(GRev) ])
            disp([ 'Gov. Spn.: ', num2str(GSpend) ])
            disp([ 'r-grn+1:   ', num2str(r-grn+1) ])
            disp([ 'G + Tr:    ', num2str(GY), '  ', num2str(TrY) ])
            disp([ 'Debt:      ', num2str(DY*Y) ])
            disp([ 'Ynet:      ', num2str(Ynet) ])
        end
    end


    % *********  BOUND POLICY VARIABLE  *********

    newPol = min(max(newPol,polMin), polMax);

% *** end function ***

